@@ -23,8 +23,9 @@
 #include "mysqlx_class_properties.h"
 #include "mysqlx_expression.h"
 #include "util/allocator.h"
+#include "util/arguments.h"
+#include "util/functions.h"
 #include "util/object.h"
-#include "util/zend_utils.h"
 
 namespace mysqlx {
 
@@ -36,11 +37,7 @@ static zend_class_entry * mysqlx_expression_class_entry;
 
 struct st_mysqlx_expression : public util::custom_allocable
 {
-	~st_mysqlx_expression()
-	{
-		zval_ptr_dtor(&expression);
-	}
-	zval expression;
+	util::zvalue expression;
 };
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_mysqlx_expression__construct, 0, ZEND_RETURN_VALUE, 1)
@@ -51,29 +48,21 @@ ZEND_END_ARG_INFO()
 MYSQL_XDEVAPI_PHP_METHOD(mysqlx_expression, __construct)
 {
 	UNUSED(return_value);
-	zval* object_zv{nullptr};
-	util::param_string expression;
+	util::raw_zval* object_zv{nullptr};
+	util::arg_string expression;
 
 	DBG_ENTER("mysqlx_expression::__construct");
 
-	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "Os",
+	if (FAILURE == util::get_method_arguments(execute_data, getThis(), "Os",
 												&object_zv, mysqlx_expression_class_entry,
 												&(expression.str), &(expression.len)))
 	{
 		DBG_VOID_RETURN;
 	}
 
-	{
-		const st_mysqlx_object* const mysqlx_object = Z_MYSQLX_P(object_zv);
-		st_mysqlx_expression* object = (st_mysqlx_expression*) mysqlx_object->ptr;
-		if (!object) {
-			php_error_docref(nullptr, E_WARNING, "invalid object of class %s", ZSTR_VAL(mysqlx_object->zo.ce->name));
-			DBG_VOID_RETURN;
-		}
-		DBG_INF_FMT("expression=[%*s]", expression.length(), expression.data());
-		ZVAL_STRINGL(&object->expression, expression.data(), expression.length());
-	}
-
+	DBG_INF_FMT("expression=[%*s]", expression.length(), expression.data());
+	st_mysqlx_expression& data_object = util::fetch_data_object<st_mysqlx_expression>(object_zv);
+	data_object.expression = expression;
 
 	DBG_VOID_RETURN;
 }
@@ -86,15 +75,15 @@ static const zend_function_entry mysqlx_expression_methods[] = {
 
 MYSQL_XDEVAPI_PHP_FUNCTION(mysql_xdevapi__expression)
 {
-	util::param_string expression;
+	util::arg_string expression;
 
 	DBG_ENTER("mysql_xdevapi__Expression");
-	if (FAILURE == util::zend::parse_function_parameters(execute_data, "s",
+	if (FAILURE == util::get_function_arguments(execute_data, "s",
 										 &expression.str, &expression.len))
 	{
 		DBG_VOID_RETURN;
 	}
-	mysqlx_new_expression(return_value, expression.to_view());
+	create_expression(expression.to_view()).move_to(return_value);
 
 	DBG_VOID_RETURN;
 }
@@ -148,40 +137,32 @@ mysqlx_unregister_expression_class(UNUSED_SHUTDOWN_FUNC_ARGS)
 	zend_hash_destroy(&mysqlx_expression_properties);
 }
 
-void
-mysqlx_new_expression(zval* return_value, const util::string_view& expression)
+util::zvalue
+create_expression(const util::string_view& expression)
 {
-	DBG_ENTER("mysqlx_new_expression");
+	DBG_ENTER("create_expression");
 
+	util::zvalue expression_obj;
 	st_mysqlx_expression& data_object{
-		util::init_object<st_mysqlx_expression>(mysqlx_expression_class_entry, return_value) };
-	ZVAL_STRINGL(&data_object.expression, expression.data(), expression.length());
+		util::init_object<st_mysqlx_expression>(mysqlx_expression_class_entry, expression_obj) };
+	data_object.expression = expression;
 
-	DBG_VOID_RETURN;
+	DBG_RETURN(expression_obj);
 }
 
-zend_bool
-is_a_mysqlx_expression(const zval * const value)
+bool
+is_expression_object(const util::zvalue& value)
 {
-	return (instanceof_function(Z_OBJCE_P(value), mysqlx_expression_class_entry));
+	return value.is_instance_of(mysqlx_expression_class_entry);
 }
 
-zval*
-get_mysqlx_expression(const zval * const object_zv)
+util::zvalue
+get_expression_object(const util::zvalue& value)
 {
-	zval* ret{nullptr};
-	DBG_ENTER("get_mysqlx_expression");
-	if (instanceof_function(Z_OBJCE_P(object_zv), mysqlx_expression_class_entry)) {
-		const st_mysqlx_object* const mysqlx_object = Z_MYSQLX_P(object_zv);
-		st_mysqlx_expression* object = (st_mysqlx_expression*) mysqlx_object->ptr;
-		if (!object) {
-			php_error_docref(nullptr, E_WARNING, "invalid object of class %s", ZSTR_VAL(mysqlx_object->zo.ce->name));
-		} else {
-			ret = &object->expression;
-		}
-
-	}
-	DBG_RETURN(ret);
+	DBG_ENTER("get_expression_object");
+	assert(is_expression_object(value));
+	st_mysqlx_expression& data_object = util::fetch_data_object<st_mysqlx_expression>(value);
+	DBG_RETURN(data_object.expression);
 }
 
 } // namespace devapi
