@@ -19,6 +19,7 @@
 #define MYSQLX_RESULT_H
 
 #include "util/allocator.h"
+#include "util/value.h"
 
 namespace mysqlx {
 
@@ -34,7 +35,7 @@ struct st_mysqlx_result : public util::custom_allocable
 	drv::st_xmysqlnd_stmt_result* result;
 };
 
-void mysqlx_new_result(zval* return_value, drv::st_xmysqlnd_stmt_result* result);
+util::zvalue create_result(drv::st_xmysqlnd_stmt_result* result);
 void mysqlx_register_result_class(INIT_FUNC_ARGS, zend_object_handlers* mysqlx_std_object_handlers);
 void mysqlx_unregister_result_class(SHUTDOWN_FUNC_ARGS);
 
