@@ -31,7 +31,7 @@
 #include "mysqlx_table__insert.h"
 #include "util/allocator.h"
 #include "util/object.h"
-#include "util/zend_utils.h"
+#include "util/functions.h"
 
 namespace mysqlx {
 
@@ -73,11 +73,11 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_table__insert, values)
 {
 	DBG_ENTER("mysqlx_table__insert::values");
 
-	zval* object_zv{nullptr};
+	util::raw_zval* object_zv{nullptr};
 	zval* values{nullptr};
 	zend_bool op_failed{FALSE};
 	int num_of_values{0};
-	if (FAILURE == util::zend::parse_method_parameters(
+	if (FAILURE == util::get_method_arguments(
 		execute_data, getThis(), "O+",
 		&object_zv,
 		mysqlx_table__insert_class_entry,
@@ -103,7 +103,7 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_table__insert, values)
 	}
 
 	if( op_failed == FALSE ) {
-		ZVAL_COPY(return_value, object_zv);
+		util::zvalue::copy_from_to(object_zv, return_value);
 	}
 
 	DBG_VOID_RETURN;
@@ -113,8 +113,8 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_table__insert, execute)
 {
 	DBG_ENTER("mysqlx_table__insert::execute");
 
-	zval* object_zv{nullptr};
-	if (FAILURE == util::zend::parse_method_parameters(execute_data, getThis(), "O",
+	util::raw_zval* object_zv{nullptr};
+	if (FAILURE == util::get_method_arguments(execute_data, getThis(), "O",
 												&object_zv, mysqlx_table__insert_class_entry))
 	{
 		DBG_VOID_RETURN;
@@ -131,22 +131,9 @@ MYSQL_XDEVAPI_PHP_METHOD(mysqlx_table__insert, execute)
 		} else {
 			xmysqlnd_stmt* stmt = data_object.table->insert(data_object.crud_op);
 			if (stmt) {
-				zval stmt_zv;
-				ZVAL_UNDEF(&stmt_zv);
-				mysqlx_new_stmt(&stmt_zv, stmt);
-				if (Z_TYPE(stmt_zv) == IS_NULL) {
-					xmysqlnd_stmt_free(stmt, nullptr, nullptr);
-				}
-				if (Z_TYPE(stmt_zv) == IS_OBJECT) {
-					zval zv;
-					ZVAL_UNDEF(&zv);
-					zend_long flags{0};
-					mysqlx_statement_execute_read_response(Z_MYSQLX_P(&stmt_zv), flags, MYSQLX_RESULT, &zv);
-
-					ZVAL_COPY(return_value, &zv);
-					zval_dtor(&zv);
-				}
-				zval_ptr_dtor(&stmt_zv);
+				util::zvalue stmt_obj = create_stmt(stmt);
+				zend_long flags{0};
+				mysqlx_statement_execute_read_response(Z_MYSQLX_P(stmt_obj.ptr()), flags, MYSQLX_RESULT).move_to(return_value);
 			}
 		}
 	}
@@ -164,8 +151,8 @@ static const zend_function_entry mysqlx_table__insert_methods[] = {
 };
 
 #if 0
-static zval *
-mysqlx_table__insert_property__name(const st_mysqlx_object* obj, zval* return_value)
+static util::raw_zval*
+mysqlx_table__insert_property__name(const st_mysqlx_object* obj, util::raw_zval* return_value)
 {
 	const st_mysqlx_table__insert* object = (const st_mysqlx_table__insert* ) (obj->ptr);
 	DBG_ENTER("mysqlx_table__insert_property__name");
@@ -241,23 +228,23 @@ mysqlx_unregister_table__insert_class(UNUSED_SHUTDOWN_FUNC_ARGS)
 	zend_hash_destroy(&mysqlx_table__insert_properties);
 }
 
-void
-mysqlx_new_table__insert(
-	zval* return_value,
+util::zvalue
+create_table_insert(
 	xmysqlnd_table* table,
 	zval* columns,
 	const int num_of_columns)
 {
-	DBG_ENTER("mysqlx_new_table__insert");
+	DBG_ENTER("create_table_insert");
+	util::zvalue table_insert_obj;
 	st_mysqlx_table__insert& data_object{
-		util::init_object<st_mysqlx_table__insert>(mysqlx_table__insert_class_entry, return_value) };
+		util::init_object<st_mysqlx_table__insert>(mysqlx_table__insert_class_entry, table_insert_obj) };
 	data_object.table = table->get_reference();
 	data_object.crud_op = xmysqlnd_crud_table_insert__create(
 		data_object.table->get_schema()->get_name(),
 		data_object.table->get_name(),
 		columns,
 		num_of_columns);
-	DBG_VOID_RETURN;
+	DBG_RETURN(table_insert_obj);
 }
 
 } // namespace devapi
