@@ -19,12 +19,9 @@
 #define MYSQL_XDEVAPI_UTIL_ZEND_UTILS_H
 
 #include <utility>
+#include "strings.h"
 
-namespace mysqlx {
-
-namespace util {
-
-namespace zend {
+namespace mysqlx::util::zend {
 
 void ensure_is_array(zval* zv);
 
@@ -34,52 +31,9 @@ void free_error_info_list(
 
 // ----------------
 
-void verify_call_parameters(
-	bool is_method,
-	zend_execute_data* execute_data,
-	const char* type_spec);
-
-template<typename ...Params>
-int parse_method_parameters(
-	zend_execute_data* execute_data,
-	zval* this_ptr,
-	const char* type_spec,
-	Params&&... params)
-{
-#ifdef MYSQL_XDEVAPI_DEV_MODE
-	verify_call_parameters(true, execute_data, type_spec);
-#endif
-	return zend_parse_method_parameters(
-		ZEND_NUM_ARGS(),
-		this_ptr,
-		type_spec,
-		std::forward<Params>(params)...);
-}
-
-template<typename ...Params>
-int parse_function_parameters(
-	zend_execute_data* execute_data,
-	const char* type_spec,
-	Params&&... params)
-{
-#ifdef MYSQL_XDEVAPI_DEV_MODE
-	verify_call_parameters(false, execute_data, type_spec);
-#endif
-	return zend_parse_parameters(
-		ZEND_NUM_ARGS(),
-		type_spec,
-		std::forward<Params>(params)...);
-}
-
-// ----------------
-
-bool is_module_loaded(const char* module_name);
+bool is_module_loaded(const string_view& module_name);
 bool is_openssl_loaded();
 
-} // namespace zend
-
-} // namespace util
-
-} // namespace mysqlx
+} // namespace mysqlx::util::zend
 
 #endif // MYSQL_XDEVAPI_UTIL_ZEND_UTILS_H
