@@ -56,13 +56,13 @@ bool Index_field::is_geojson() const
 
 bool Index_field::is_required() const
 {
-	return required ? required.get() : is_geojson();
+	return required ? required.value() : is_geojson();
 }
 
 // -----------------------------------------------------------------------------
 
 Index_definition::Index_definition(const util::string_view& index_name)
-	: name(index_name.to_string())
+	: name(index_name)
 	, is_unique(false) //TODO temporary - shouldn't be needed in future version of server
 {
 	if (index_name.empty())	{
@@ -70,7 +70,7 @@ Index_definition::Index_definition(const util::string_view& index_name)
 	}
 }
 
-boost::optional<util::string> Index_definition::get_type_str() const
+std::optional<util::string> Index_definition::get_type_str() const
 {
 	using Type_to_str = std::map<Index_definition::Type, std::string>;
 	static const Type_to_str type_to_str = {
@@ -78,8 +78,10 @@ boost::optional<util::string> Index_definition::get_type_str() const
 		{ Index_definition::Type::Spatial, "SPATIAL" }
 	};
 
-	if (type) return util::to_string(type_to_str.at(type.get()));
-	return boost::optional<util::string>();
+	if (type) {
+		return util::to_string(type_to_str.at(type.value()));
+	}
+	return std::nullopt;
 }
 
 /****************************** COLLECTION.CREATE_INDEX() *******************************************************/
@@ -89,8 +91,8 @@ namespace
 
 struct collection_create_index_var_binder_ctx
 {
-	const util::string_view& schema_name;
-	const util::string_view& collection_name;
+	const util::string_view schema_name;
+	const util::string_view collection_name;
 	const Index_definition& index_def;
 };
 
@@ -189,7 +191,7 @@ bool collection_create_index_execute(
 {
 	DBG_ENTER("collection_create_index_execute");
 
-	const MYSQLND_CSTRING query{"create_collection_index", sizeof("create_collection_index") - 1 };
+	constexpr util::string_view query("create_collection_index");
 
 	collection_create_index_var_binder_ctx var_binder_ctx{
 		schema_name,
@@ -223,9 +225,9 @@ namespace
 
 struct collection_drop_index_var_binder_ctx
 {
-	const util::string_view& schema_name;
-	const util::string_view& collection_name;
-	const util::string_view& index_name;
+	const util::string_view schema_name;
+	const util::string_view collection_name;
+	const util::string_view index_name;
 };
 
 const enum_hnd_func_status
@@ -261,7 +263,7 @@ bool collection_drop_index_execute(
 {
 	DBG_ENTER("xmysqlnd_collection_drop_index__execute");
 
-	const MYSQLND_CSTRING query{"drop_collection_index", sizeof("drop_collection_index") - 1 };
+	constexpr util::string_view query("drop_collection_index");
 
 	collection_drop_index_var_binder_ctx var_binder_ctx{
 		schema_name,
